import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { Card, Row, Col, Form, InputGroup, Button } from 'react-bootstrap';
import { Eye } from 'lucide-react';
import RangeSlider from './RangeSlider';
import {
    setCategory,
    toggleEcommerceRating,
    toggleExposureRating,
    toggleGmvRange,
    setViewsRange,
    resetFilters,
} from '../store/slices/filtersSlice';
import { fetchCreators } from '../store/slices/creatorsSlice';
import '../styles/DatabaseFilter.scss';

export default function DatabaseFilter({ path }) {
    const dispatch = useDispatch();
    const filters = useSelector((state) => state.filters);

    // 类别选项数据
    const categories = [
        'Phones & Electronics',
        'Homes Supplies',
        'Kitchenware',
        'Textiles & Soft Furnishings',
        'Household Appliances',
    ];

    // 电商评级数据
    const ecommerceRatings = ['L1', 'L2', 'L3', 'L4', 'L5', 'L6', 'L7'];

    // 曝光评级数据
    const exposureRatings = ['KOC-1', 'KOC-2', 'KOL-1', 'KOL-2', 'KOL-3'];

    // GMV 范围选项
    const gmvRanges = [
        { label: '$0 - $5k', min: 0, max: 5000 },
        { label: '$5k - $25k', min: 5000, max: 25000 },
        { label: '$25k - $60k', min: 25000, max: 60000 },
        { label: '$60k - $150k', min: 60000, max: 150000 },
        { label: '$150k - $400k', min: 150000, max: 400000 },
        { label: '$400k - $1500k', min: 400000, max: 1500000 },
        { label: '$1500k+', min: 1500000, max: Number.MAX_SAFE_INTEGER },
    ];

    // 预定义的离散点值
    const discreteValues = [0, 100, 1000, 10000, 100000, 250000, 500000];

    // 找到最接近的离散值索引
    const findClosestDiscreteIndex = (value) => {
        let closestIndex = 0;
        let minDiff = Math.abs(discreteValues[0] - value);

        for (let i = 1; i < discreteValues.length; i++) {
            const diff = Math.abs(discreteValues[i] - value);
            if (diff < minDiff) {
                minDiff = diff;
                closestIndex = i;
            }
        }

        return closestIndex;
    };

    // 本地状态用于表单控制
    const [minViews, setMinViews] = useState(filters.viewsRange[0]);
    const [maxViews, setMaxViews] = useState(filters.viewsRange[1]);

    // 监听Redux状态变化，更新本地表单状态
    useEffect(() => {
        setMinViews(filters.viewsRange[0]);
        setMaxViews(filters.viewsRange[1]);
    }, [filters.viewsRange]);

    // 组件加载时获取数据
    useEffect(() => {
        dispatch(fetchCreators({ path }));
    }, [dispatch, filters]);

    // 处理类别选择
    const handleCategorySelect = (category) => {
        dispatch(setCategory(category));
    };

    // 处理电商评级选择
    const handleEcommerceRatingSelect = (rating) => {
        dispatch(toggleEcommerceRating(rating));
    };

    // 处理曝光评级选择
    const handleExposureRatingSelect = (rating) => {
        dispatch(toggleExposureRating(rating));
    };

    // 处理GMV范围选择
    const handleGmvRangeSelect = (range) => {
        dispatch(toggleGmvRange(range));
    };

    // 处理视图范围更新
    const handleViewsRangeChange = (newRange) => {
        dispatch(setViewsRange(newRange));
    };

    // 处理min input变更
    const handleMinViewsChange = (e) => {
        const inputValue = parseInt(e.target.value) || 0;
        setMinViews(inputValue);
    };

    // 处理max input变更
    const handleMaxViewsChange = (e) => {
        const inputValue = parseInt(e.target.value) || 0;
        setMaxViews(inputValue);
    };

    // 当输入框失去焦点时，转换为最接近的离散值
    const handleInputBlur = (type) => {
        if (type === 'min') {
            // 找到最接近的离散值
            const closestIndex = findClosestDiscreteIndex(minViews);
            const discreteValue = discreteValues[closestIndex];

            // 确保最小值不超过最大值
            const finalValue = Math.min(discreteValue, maxViews);

            setMinViews(finalValue);
            dispatch(setViewsRange([finalValue, filters.viewsRange[1]]));
        } else {
            // 找到最接近的离散值
            const closestIndex = findClosestDiscreteIndex(maxViews);
            const discreteValue = discreteValues[closestIndex];

            // 确保最大值不小于最小值
            const finalValue = Math.max(discreteValue, minViews);

            setMaxViews(finalValue);
            dispatch(setViewsRange([filters.viewsRange[0], finalValue]));
        }
    };

    // 格式化显示值的函数
    const formatValue = (value) => {
        if (value >= 1000000) {
            return `${(value / 1000000).toFixed(1)}M`;
        }
        if (value >= 1000) {
            return `${(value / 1000).toFixed(0)}k`;
        }
        return value;
    };

    return (
        <div className='shadow-sm mb-4 filter-card'>
            <Card.Body>
                <h3 className='mb-4'>Filter</h3>

                {/* 类别筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>Category</h5>
                    <div className='filter-options'>
                        {categories.map((category) => (
                            <Button
                                key={category}
                                variant={filters.category.includes(category) ? 'primary' : 'light'}
                                className='rounded-pill'
                                onClick={() => handleCategorySelect(category)}
                            >
                                {category}
                            </Button>
                        ))}
                    </div>
                </div>

                {/* 电商评级筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>E-commerce Rating</h5>
                    <div className='filter-options'>
                        {ecommerceRatings.map((rating) => (
                            <Button
                                key={rating}
                                variant={filters.ecommerceRatings.includes(rating) ? 'primary' : 'light'}
                                className='rounded-pill'
                                onClick={() => handleEcommerceRatingSelect(rating)}
                            >
                                {rating}
                            </Button>
                        ))}
                    </div>
                </div>

                {/* 曝光评级筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>Exposure Rating</h5>
                    <div className='filter-options'>
                        {exposureRatings.map((rating) => (
                            <Button
                                key={rating}
                                variant={filters.exposureRatings.includes(rating) ? 'primary' : 'light'}
                                className='rounded-pill'
                                onClick={() => handleExposureRatingSelect(rating)}
                            >
                                {rating}
                            </Button>
                        ))}
                    </div>
                </div>

                {/* GMV筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>GMV</h5>
                    <div className='filter-options'>
                        {gmvRanges.map((range) => (
                            <Button
                                key={range.label}
                                variant={filters.gmvRanges.includes(range.label) ? 'primary' : 'light'}
                                className='rounded-pill'
                                onClick={() => handleGmvRangeSelect(range.label)}
                            >
                                {range.label}
                            </Button>
                        ))}
                    </div>
                </div>

                {/* 视频观看量筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>Views</h5>
                    <div className='filter-options filter-views'>
                        <RangeSlider
                            min={0}
                            max={500000}
                            value={filters.viewsRange}
                            onChange={handleViewsRangeChange}
                        />

                        <div className='range-input'>
                            <InputGroup>
                                <InputGroup.Text>
                                    <Eye size={16} />
                                </InputGroup.Text>
                                <Form.Control
                                    type='number'
                                    value={minViews}
                                    onChange={handleMinViewsChange}
                                    onBlur={() => handleInputBlur('min')}
                                />
                            </InputGroup>
                            <span>-</span>
                            <InputGroup>
                                <InputGroup.Text>
                                    <Eye size={16} />
                                </InputGroup.Text>
                                <Form.Control
                                    type='number'
                                    value={maxViews}
                                    onChange={handleMaxViewsChange}
                                    onBlur={() => handleInputBlur('max')}
                                />
                            </InputGroup>
                        </div>
                    </div>
                </div>
            </Card.Body>
        </div>
    );
}
