import React, { useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { Table, Form, Spinner } from 'react-bootstrap';
import { ChevronUp, ChevronDown } from 'lucide-react';
import {
    fetchCreators,
    toggleCreatorSelection,
    selectAllCreators,
    clearCreatorSelection,
} from '../store/slices/creatorsSlice';
import { setSortBy } from '../store/slices/filtersSlice';
import '../styles/DatabaseList.scss';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

export default function DatabaseList({ path }) {
    const dispatch = useDispatch();
    const { creators, status, selectedCreators } = useSelector((state) => state.creators);
    const { sortBy, sortDirection } = useSelector((state) => state.filters);

    // 组件加载时获取创作者数据
    useEffect(() => {
        if (status === 'idle') {
            dispatch(fetchCreators({path}));
        }
    }, [dispatch, status]);

    useEffect(() => {
        // console.log(creators);
    }, [creators]);
    // 处理全选/取消全选
    const handleSelectAll = (e) => {
        if (e.target.checked) {
            dispatch(selectAllCreators());
        } else {
            dispatch(clearCreatorSelection());
        }
    };

    // 处理单个创作者选择
    const handleSelectCreator = (creatorId) => {
        dispatch(toggleCreatorSelection(creatorId));
    };

    // 处理排序
    const handleSort = (field) => {
        dispatch(setSortBy(field));
    };

    // 渲染排序图标
    const renderSortIcon = (field) => {
        if (sortBy === field) {
            return sortDirection === 'asc' ? <ChevronUp size={14} /> : <ChevronDown size={14} />;
        }
        return null;
    };

    // 根据类别获取样式类名
    const getCategoryClassName = (category) => {
        const categoryMap = {
            'Phones & Electronics': 'phones',
            'Womenswear & Underwear': 'women',
            'Sports & Outdoor': 'sports',
            'Food & Beverage': 'food',
            Health: 'health',
            Kitchenware: 'kitchen',
        };

        return categoryMap[category] || '';
    };

    // 如果正在加载，显示加载中
    if (status === 'loading') {
        return (
            <div className='text-center p-5'>
                <Spinner animation='border' role='status'>
                    <span className='visually-hidden'>Loading...</span>
                </Spinner>
            </div>
        );
    }

    // 如果加载失败，显示错误信息
    if (status === 'failed') {
        return <div className='alert alert-danger'>Failed to load creators. Please try again later.</div>;
    }

    return (
        <div className='creator-database-table'>
            <Table responsive hover className='bg-white shadow-sm rounded overflow-hidden'>
                <thead>
                    <tr>
                        <th className='selector' style={{ width: '40px' }}>
                            <Form.Check
                                type='checkbox'
                                checked={selectedCreators.length === creators.length && creators.length > 0}
                                onChange={handleSelectAll}
                            />
                        </th>
                        <th className='creator' onClick={() => handleSort('name')} style={{ width: '180px' }}>
                            Creator {renderSortIcon('name')}
                        </th>
                        <th
                            className='category text-center'
                            onClick={() => handleSort('category')}
                            style={{ width: '180px' }}
                        >
                            Category {renderSortIcon('category')}
                        </th>
                        <th className='e-commerce-level text-center' onClick={() => handleSort('ecommerceLevel')}>
                            E-commerce Level {renderSortIcon('ecommerceLevel')}
                        </th>
                        <th className='exposure-level text-center' onClick={() => handleSort('exposureLevel')}>
                            Exposure Level {renderSortIcon('exposureLevel')}
                        </th>
                        <th className='followers text-center' onClick={() => handleSort('followers')}>
                            Followers {renderSortIcon('followers')}
                        </th>
                        <th className='gmv text-center' onClick={() => handleSort('gmv')}>
                            GMV {renderSortIcon('gmv')}
                        </th>
                        <th className='views text-center' onClick={() => handleSort('avgViews')}>
                            Avg. Video Views {renderSortIcon('avgViews')}
                        </th>
                        <th className='e-commerce text-center'>E-commerce</th>
                        <th className='profile text-center'>Profile</th>
                    </tr>
                </thead>
                <tbody>
                    {creators.length === 0 ? (
                        <tr>
                            <td colSpan='10' className='text-center py-4'>
                                No creators found matching your filters.
                            </td>
                        </tr>
                    ) : (
                        creators.map((creator) => (
                            <tr key={creator.id} className={selectedCreators.includes(creator.id) ? 'selected' : ''}>
                                <td>
                                    <Form.Check
                                        type='checkbox'
                                        checked={selectedCreators.includes(creator.id)}
                                        onChange={() => handleSelectCreator(creator.id)}
                                    />
                                </td>
                                <td className='creator-cell'>
                                    <div className='d-flex align-items-center'>
                                        <div className='creator-avatar'>
                                            <img src={creator.avatar} alt={creator.name} />
                                            {creator.verified && <span className='verified-badge'></span>}
                                        </div>
                                        <div className='creator-name'>{creator.name}</div>
                                    </div>
                                </td>
                                <td>
                                    <span className={`category-pill ${getCategoryClassName(creator.category)}`}>
                                        {creator.category}
                                    </span>
                                </td>
                                <td className='text-center'>
                                    <span className='level-badge ecommerce-level'>{creator.ecommerceLevel}</span>
                                </td>
                                <td className='text-center'>
                                    <span className='level-badge exposure-level' data-level={creator.exposureLevel}>
                                        {creator.exposureLevel}
                                    </span>
                                </td>
                                <td className='text-nowrap text-center'>{creator.followers}</td>
                                <td className='text-center'>
                                    <div>{creator.gmv}</div>
                                    <div className='small text-muted'>Items Sold: {creator.soldPercentage}</div>
                                </td>
                                <td className='text-nowrap text-center'>{creator.avgViews}</td>
                                <td className='text-center'>
                                    {creator.hasEcommerce ? <div className='colored-dot blue mx-auto'></div> : null}
                                </td>
                                <td className='text-center'>
                                    {creator.hasTiktok && (
                                        <div className='social-icon tiktok-icon mx-auto'>
                                            <FontAwesomeIcon icon='fa-brands fa-tiktok' />
                                        </div>
                                    )}
                                </td>
                            </tr>
                        ))
                    )}
                </tbody>
            </Table>
        </div>
    );
}
