import React, { useEffect, useState } from 'react';
import { Table, Form } from 'react-bootstrap';
import { useSelector, useDispatch } from 'react-redux';
import { useParams } from 'react-router-dom';
import '../styles/Products.scss';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

export default function ProductsList() {
    const { brandId } = useParams();
    const { brands } = useSelector((state) => state.brands);
    const [products, setProducts] = useState([]);
    const [selectedProducts, setSelectedProducts] = useState([]);
    const [sortField, setSortField] = useState(null);
    const [sortDirection, setSortDirection] = useState('asc');

    useEffect(() => {
        if (brands.length > 0) {
            const brand = brands.find((b) => b.id.toString() === brandId);
            if (brand && brand.products) {
                setProducts(brand.products);
            }
        }
    }, [brands, brandId]);

    const handleSort = (field) => {
        if (sortField === field) {
            setSortDirection(sortDirection === 'asc' ? 'desc' : 'asc');
        } else {
            setSortField(field);
            setSortDirection('asc');
        }
    };

    const renderSortIcon = (field) => {
        if (sortField !== field) return null;
        return sortDirection === 'asc' ? '↑' : '↓';
    };

    const handleSelectAll = (e) => {
        if (e.target.checked) {
            setSelectedProducts(products.map((product) => product.id));
        } else {
            setSelectedProducts([]);
        }
    };

    const handleSelectProduct = (productId) => {
        if (selectedProducts.includes(productId)) {
            setSelectedProducts(selectedProducts.filter((id) => id !== productId));
        } else {
            setSelectedProducts([...selectedProducts, productId]);
        }
    };

    return (
        <div className='products-list'>
            <Table responsive hover className='bg-white shadow-xs rounded overflow-hidden'>
                <thead>
                    <tr>
                        <th className='selector' style={{ width: '40px' }}>
                            <Form.Check
                                type='checkbox'
                                checked={selectedProducts.length === products.length && products.length > 0}
                                onChange={handleSelectAll}
                            />
                        </th>
                        <th className='product' onClick={() => handleSort('name')}>
                            Product {renderSortIcon('name')}
                        </th>
                        <th className='commission text-center' onClick={() => handleSort('commission')}>
                            Commission Rate {renderSortIcon('commission')}
                        </th>
                        <th className='samples text-center' onClick={() => handleSort('availableSamples')}>
                            Available Samples {renderSortIcon('availableSamples')}
                        </th>
                        <th className='price text-center' onClick={() => handleSort('price')}>
                            Sales Price {renderSortIcon('price')}
                        </th>
                        <th className='stock text-center' onClick={() => handleSort('stock')}>
                            Stock {renderSortIcon('stock')}
                        </th>
                        <th className='sold text-center' onClick={() => handleSort('sold')}>
                            Items Sold {renderSortIcon('sold')}
                        </th>
                        <th className='rating text-center' onClick={() => handleSort('rating')}>
                            Product Rating {renderSortIcon('rating')}
                        </th>
                        <th className='creators text-center' onClick={() => handleSort('collabCreators')}>
                            Collab. Creators {renderSortIcon('collabCreators')}
                        </th>
                        <th className='tiktokShop text-center' onClick={() => handleSort('tiktokShop')}>
                            TikTok Shop {renderSortIcon('tiktokShop')}
                        </th>
                    </tr>
                </thead>
                <tbody>
                    {products.length === 0 ? (
                        <tr>
                            <td colSpan='10' className='text-center py-4'>
                                No products found for this brand.
                            </td>
                        </tr>
                    ) : (
                        products.map((product) => (
                            <tr key={product.id} className={selectedProducts.includes(product.id) ? 'selected' : ''}>
                                <td>
                                    <Form.Check
                                        type='checkbox'
                                        checked={selectedProducts.includes(product.id)}
                                        onChange={() => handleSelectProduct(product.id)}
                                    />
                                </td>
                                <td className='product-cell'>
                                    <div className='d-flex align-items-center'>
                                        <div className='product-logo'>{product.name.slice(0, 1)}</div>
                                        <div className='product-name'>{product.name}</div>
                                    </div>
                                </td>
                                <td className='text-center'	>
                                    <div>{product.commission}</div>
                                    <div className='small text-muted'>Open collab. {product.openCollab}</div>
                                </td>
                                <td className='text-center'>{product.availableSamples}</td>
                                <td className='text-center'>{product.price}</td>
                                <td className='text-center'>{product.stock}</td>
                                <td className='text-center'>{product.sold}</td>
                                <td className='text-center'>
                                    <div>{product.rating}</div>
                                    <div className='small text-muted'>{product.reviews} Reviews</div>
                                </td>
                                <td className='text-center'>{product.collabCreators}</td>
                                <td className='text-center'>{product.tiktokShop && <FontAwesomeIcon icon='fa-brands fa-tiktok' />}</td>
                            </tr>
                        ))
                    )}
                </tbody>
            </Table>
        </div>
    );
}
